@@ -30,7 +30,9 @@ class IsEndSymbol(Criteria):
 
     def accept(self, state: StrSequence) -> bool:
         if SYMBOLS['end_symbols'].match(state.current_value) and \
-                not (SYMBOLS['en_dot'].match(state.next_value) or SYMBOLS['end_symbols'].match(state.next_value)):
+                not (SYMBOLS['en_dot'].match(state.next_value)
+                     or SYMBOLS['end_symbols'].match(state.next_value)
+                     or SYMBOLS['special_symbols'].match(state.next_value)):
             return True
         if SYMBOLS['en_dot'].match(state.current_value):
             if self.is_zh(state.next_value) or self.empty.match(state.next_value):
@@ -217,11 +219,10 @@ class WithSays(SpecialCondition):
 class SpecialEnds(SpecialCondition):
     def __init__(self):
         super(SpecialEnds, self).__init__('SpecialEnds')
-        self.pattern_pre = re.compile('([~～])')
         self.pattern_cur = re.compile('\s')
 
     def accept(self, state: StrSequence) -> bool:
-        if self.pattern_pre.match(state.pre_value) and self.pattern_cur.match(state.current_value):
+        if SYMBOLS['special_symbols'].match(state.pre_value) and self.pattern_cur.match(state.current_value):
             return True
         else:
             return False
